@@ -20,6 +20,8 @@ use FusionInventory::Agent::Tools::Network;
 use FusionInventory::Agent::Tools::Unix;
 
 sub isEnabled {
+    my (%params) = @_;
+    return 0 if $params{no_category}->{network};
     return canRun('ifconfig');
 }
 
@@ -29,20 +31,15 @@ sub doInventory {
     my $inventory = $params{inventory};
     my $logger    = $params{logger};
 
-    # set list of network interfaces
-    my $routes     = getRoutingTable(logger => $logger);
     my @interfaces = _getInterfaces(logger => $logger);
-
     foreach my $interface (@interfaces) {
-        $interface->{IPGATEWAY} = $params{routes}->{$interface->{IPSUBNET}}
-            if $interface->{IPSUBNET};
-
         $inventory->addEntry(
             section => 'NETWORKS',
             entry   => $interface
         );
     }
 
+    my $routes = getRoutingTable(logger => $logger);
     $inventory->setHardware({
         DEFAULTGATEWAY => $routes->{'0.0.0.0'}
     });
@@ -57,6 +54,11 @@ sub _getInterfaces {
     );
 
     foreach my $interface (@interfaces) {
+        $interface->{IPSUBNET} = getSubnetAddress(
+            $interface->{IPADDRESS},
+            $interface->{IPMASK}
+        );
+
         if ($interface->{DESCRIPTION} =~ /^(\S+)(\d+)/) {
             my $nic = $1;
             my $num = $2;
@@ -71,11 +73,6 @@ sub _getInterfaces {
                 $nic =~ /e1000g/ ? _check_ce_nic($nic, $num)   :
                                    _check_nic($nic, $num);
         }
-
-        $interface->{IPSUBNET} = getSubnetAddress(
-            $interface->{IPADDRESS},
-            $interface->{IPMASK}
-        );
     }
 
     my $zone = getZone();
@@ -303,15 +300,24 @@ sub _parsefcinfo {
     my $inc = 1;
     my $interface;
     while (my $line = <$handle>) {
-        $interface->{DESCRIPTION} = "HBA_Port_WWN_" . $inc if $line =~ /HBA Port WWN:\s+(\S+)/;
-        $interface->{DESCRIPTION} .= " " . $1 if $line =~ /OS Device Name:\s+(\S+)/;
-        $interface->{SPEED} = $1 if $line =~ /Current Speed:\s+(\S+)/;
-        $interface->{WWN} = $1 if $line =~ /Node WWN:\s+(\S+)/;
-        $interface->{DRIVER} = $1 if $line =~ /Driver Name:\s+(\S+)/i;
-        $interface->{MANUFACTURER} = $1 if $line =~ /Manufacturer:\s+(.*)$/;
-        $interface->{MODEL} = $1 if $line =~ /Model:\s+(.*)$/;
-        $interface->{FIRMWARE} = $1 if $line =~ /Firmware Version:\s+(.*)$/;
-        $interface->{STATUS} = 'Up' if $line =~ /online/;
+        $interface->{DESCRIPTION} = "HBA_Port_WWN_" . $inc
+            if $line =~ /HBA Port WWN:\s+(\S+)/;
+        $interface->{DESCRIPTION} .= " " . $1
+            if $line =~ /OS Device Name:\s+(\S+)/;
+        $interface->{SPEED} = $1
+            if $line =~ /Current Speed:\s+(\S+)/;
+        $interface->{WWN} = $1
+            if $line =~ /Node WWN:\s+(\S+)/;
+        $interface->{DRIVER} = $1
+            if $line =~ /Driver Name:\s+(\S+)/i;
+        $interface->{MANUFACTURER} = $1
+            if $line =~ /Manufacturer:\s+(.*)$/;
+        $interface->{MODEL} = $1
+            if $line =~ /Model:\s+(.*)$/;
+        $interface->{FIRMWARE} = $1
+            if $line =~ /Firmware Version:\s+(.*)$/;
+        $interface->{STATUS} = 'Up'
+            if $line =~ /online/;
 
         if ($interface->{DESCRIPTION} && $interface->{WWN}) {
             $interface->{STATUS} = 'Down' if !$interface->{STATUS};
