@@ -21,9 +21,7 @@ use FusionInventory::Agent::Tools::Win32;
 
 sub isEnabled {
     my (%params) = @_;
-
-    return if $params{no_category}->{user};
-
+    return 0 if $params{no_category}->{user};
     return 1;
 }
 
@@ -75,11 +73,12 @@ sub _getLocalUsers {
     my @users;
 
     foreach my $object (in $WMIService->ExecQuery($query)) {
-
-        push @users, {
+        my $user = {
             NAME => $object->{Name},
             ID   => $object->{SID},
         };
+        utf8::upgrade($user->{NAME});
+        push @users, $user;
     }
 
     return @users;
@@ -97,11 +96,12 @@ sub _getLocalGroups {
     my @groups;
 
     foreach my $object (in $WMIService->ExecQuery($query)) {
-
-        push @groups, {
+        my $group = {
             NAME => $object->{Name},
             ID   => $object->{SID},
         };
+        utf8::upgrade($group->{NAME});
+        push @groups, $group;
     }
 
     return @groups;
